summaryrefslogtreecommitdiffstats
path: root/partitions.py
diff options
context:
space:
mode:
authorJeremy Katz <katzj@redhat.com>2005-05-19 21:34:02 +0000
committerJeremy Katz <katzj@redhat.com>2005-05-19 21:34:02 +0000
commit07cda6895fcfd9dc94de76d7d70ac8f855f25c2e (patch)
tree7959b40066f54827273fd2250522a0659daf607c /partitions.py
parentcbc4b83ae0fc8dcd1abd11b2e619399f56f59f33 (diff)
downloadanaconda-07cda6895fcfd9dc94de76d7d70ac8f855f25c2e.tar.gz
anaconda-07cda6895fcfd9dc94de76d7d70ac8f855f25c2e.tar.xz
anaconda-07cda6895fcfd9dc94de76d7d70ac8f855f25c2e.zip
2005-05-19 Jeremy Katz <katzj@redhat.com>
* fsset.py (prepbootFileSystem.__init__): PReP partitions should be marked bootable, from Dustin Kirkland. * raid.py (availRaidLevels): Allow ppc to have a RAID /boot, from Dustin Kirkland. * partitions.py (Partitions.getBootableRequest): Split PMac/pSeries handling to be different. pSeries can do bootable PReP. Patch from Dustin Kirkland <dustin.kirkland@us.ibm.com>
Diffstat (limited to 'partitions.py')
-rw-r--r--partitions.py27
1 files changed, 21 insertions, 6 deletions
diff --git a/partitions.py b/partitions.py
index 12649e44c..3bc795955 100644
--- a/partitions.py
+++ b/partitions.py
@@ -6,7 +6,7 @@
# Mike Fulbright <msf@redhat.com>
# Harald Hoyer <harald@redhat.de>
#
-# Copyright 2002 Red Hat, Inc.
+# Copyright 2002-2005 Red Hat, Inc.
#
# This software may be freely redistributed under the terms of the GNU
# library public license.
@@ -619,8 +619,7 @@ class Partitions:
if req.fstype == fsset.fileSystemTypeGet("PPC PReP Boot"):
return [ req ]
return None
- elif (iutil.getPPCMachine() == "pSeries" or
- iutil.getPPCMachine() == "PMac"):
+ elif (iutil.getPPCMachine() == "pSeries"):
# pSeries and Mac bootable requests are odd.
# have to consider both the PReP or Bootstrap partition (with
# potentially > 1 existing) as well as /boot,/
@@ -629,12 +628,28 @@ class Partitions:
boottype = "PPC PReP Boot"
else:
boottype = "Apple Bootstrap"
-
- # for the prep partition, we want either the first or the
+
+ ret = []
+ for req in self.requests:
+ if req.fstype == fsset.fileSystemTypeGet("PPC PReP Boot"):
+ ret.append(req)
+
+ # now add the /boot
+ bootreq = self.getRequestByMountPoint("/boot")
+ if not bootreq:
+ bootreq = self.getRequestByMountPoint("/")
+ if bootreq:
+ ret.append(bootreq)
+
+ if len(ret) >= 1:
+ return ret
+ return None
+ elif (iutil.getPPCMachine() == "PMac"):
+ # for the bootstrap partition, we want either the first or the
# first non-preexisting one
bestprep = None
for req in self.requests:
- if req.fstype == fsset.fileSystemTypeGet(boottype):
+ if req.fstype == fsset.fileSystemTypeGet("Apple Bootstrap"):
if ((bestprep is None) or
(bestprep.getPreExisting() and
not req.getPreExisting())):